==> samizdat_0.6.1.orig.tar.gz: samizdat/lib/samizdat/engine/controller.rb <==
# Samizdat controller class
#
#   Copyright (c) 2002-2007  Dmitry Borodaenko <angdraug@debian.org>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU General Public License version 2 or later.
#
# vim: et sw=2 sts=2 ts=8 tw=0

require 'samizdat/engine'
require 'samizdat/helpers/application_helper'

class Controller
  include ApplicationHelper

  def initialize(request, id=nil)
    @request = request
    @session = @request.session
    @id = id

    @layout = 'page_layout.rhtml'
    @template = default_template

    @title = nil
    @content_for_layout = nil

    # response headers
    @headers = {}

    # rss feeds
    @feeds = {}

    # document navigation links (made, start, next, ...)
    @links = { :start => @request.base,
               :icon => config['site']['icon'] }
  end

  def render
    @content_for_layout ||= View.render(self, @template)
    @request.response(@headers,
      @layout ? View.render(self, @layout) : @content_for_layout)
  end

  private

  def default_template
    self.class.to_s.sub(/Controller\z/, '').downcase + '.rhtml'
  end

  # check if moderatorial action is allowed
  #
  def assert_moderate
    @request.moderate? or raise AuthError,
      _('Moderator access privilege is required')
  end

  # log moderatorial action (run inside transaction)
  #
  def log_moderation(action)
    (@session.member and @id) or raise RuntimeError,
      'Not enough data to log moderation'

    db.do 'INSERT INTO Moderation (moderator, action, resource)
      VALUES (?, ?, ?)', @session.member, action, @id
  end
end

# generate error page on exceptions
#
class ErrorController < Controller
  def _error(error)
    case error
    when AuthError
      @headers['status'] = 'AUTH_REQUIRED'
      @title = _('Access Denied')
      @content_for_layout = %{<p>#{error}.</p>}

    when AccountBlockedError
      @title = _('Account Is Blocked')
      @content_for_layout =
'<p>'+_('Your account is blocked until the email address you have specified is confirmed. Confirmation message with instructions was sent to that address.')+'</p>'

    when UserError
      @title = _('User Error')
      @content_for_layout =
%{<p>#{error}.</p><p>}+_("Press 'Back' button of your browser to return.")+'</p>'

    when ResourceNotFoundError
      @headers['status'] = 'NOT_FOUND'
      @title = _('Resource Not Found')
      referer = sprintf(_(' (looks like it was %s)'), %{<a href="#{@request.referer}">#{@request.referer}</a>}) if @request.referer
      @content_for_layout =
'<p>' + sprintf(_('The resource you requested (%s) was not found on this site. Please report this error back to the site you came from%s.'), CGI.escapeHTML(error.message), referer.to_s) + '</p>'

    else
      error_id = log_exception(error, @request)

      @headers['status'] = 'SERVER_ERROR'
      @title = _('Runtime Error')
      @content_for_layout =
'<p>'+_('Runtime error has occured.')+%{ Error ID: #{CGI.escapeHTML(error_id)}.</p>
<p>}+_('Please report this error to the site administrator.')+'</p>'
    end

    @content_for_layout = box(@title, @content_for_layout)
  end
end

==> samizdat_0.6.2.orig.tar.gz: samizdat/lib/samizdat/engine/controller.rb <==
# Samizdat controller class
#
#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU General Public License version 3 or later.
#
# vim: et sw=2 sts=2 ts=8 tw=0

require 'samizdat/engine'
require 'samizdat/helpers/application_helper'

class Controller
  include ApplicationHelper

  def initialize(request, id=nil)
    @request = request
    @session = @request.session
    @member = Member.cached(@session.member)

    @id = id

    @layout = 'page_layout.rhtml'
    @template = default_template

    @title = nil
    @content_for_layout = nil

    # response headers
    @headers = {}

    # rss feeds
    @feeds = {}

    # document navigation links (made, start, next, ...)
    @links = { :start => @request.base,
               :icon => config['site']['icon'] }

    # JavaScript libraries
    @js = [ 'flashembed' ]
  end

  def render
    @content_for_layout ||= View.render(self, @template)

    if @request.notice
      @content_for_layout =
        '<div class="notice">' + @request.notice + '</div>' +
        @content_for_layout
      @request.reset_notice
    end

    @request.response(@headers,
      @layout ? View.render(self, @layout) : @content_for_layout)
  end

  private

  def default_template
    self.class.to_s.sub(/Controller\z/, '').downcase + '.rhtml'
  end

  # check if moderatorial action is allowed
  #
  def assert_moderate
    @member.assert_allowed_to('moderate')
  end

  # log moderatorial action (run inside transaction)
  #
  def log_moderation(action)
    (@session.member and @id) or raise RuntimeError,
      'Not enough data to log moderation'

    db.do 'INSERT INTO Moderation (moderator, action, resource)
      VALUES (?, ?, ?)', @session.member, action, @id
  end
end

# generate error page on exceptions
#
class ErrorController < Controller
  def _error(error)
    case error
    when AuthError
      @headers['status'] = 'AUTH_REQUIRED'
      @title = _('Access Denied')
      @content_for_layout = %{<p>#{error}.</p>}

    when AccountBlockedError
      @title = _('Account Is Blocked')
      @content_for_layout =
'<p>'+_('Your account is blocked until the email address you have specified is confirmed. Confirmation message with instructions was sent to that address.')+'</p>'

    when UserError
      @title = _('User Error')
      @content_for_layout =
%{<p>#{error}.</p><p>}+_("Press 'Back' button of your browser to return.")+'</p>'

    when ResourceNotFoundError
      @headers['status'] = 'NOT_FOUND'
      @title = _('Resource Not Found')
      referer = sprintf(_(' (looks like it was %s)'), %{<a href="#{@request.referer}">#{@request.referer}</a>}) if @request.referer
      @content_for_layout =
'<p>' + sprintf(_('The resource you requested (%s) was not found on this site. Please report this error back to the site you came from%s.'), CGI.escapeHTML(error.message), referer.to_s) + '</p>'

    else
      error_id = log_exception(error, @request)

      @headers['status'] = 'SERVER_ERROR'
      @title = _('Runtime Error')
      @content_for_layout =
'<p>'+_('Runtime error has occured.')+%{ Error ID: #{CGI.escapeHTML(error_id)}.</p>
<p>}+_('Please report this error to the site administrator.')+'</p>'
    end

    @content_for_layout = box(@title, @content_for_layout)
  end
end
